﻿Imports System.Drawing.Printing

Public Class CheckWriterForm

   ' PrintPage event raised for each page to be printed
   Private Sub document_PrintPage(ByVal sender _
      As System.Object, ByVal e As PrintPageEventArgs)

      Dim fontObject As Font ' variable to store font

      ' store a control's x- and y-coordinates
      Dim yPosition As Single
      Dim xPosition As Single

      ' represent left margin of page
      Dim leftMargin As Single = e.MarginBounds.Left

      ' represent top margin of page
      Dim topMargin As Single = e.MarginBounds.Top

      ' store a control's text
      Dim controlText As String = Nothing

      ' iterate over the controls on the Form,
      ' printing the text displayed in each control
      For Each controlObject As Control In Me.Controls
         ' do not print Buttons
         If Not (TypeOf controlObject Is Button) Then
            controlText = controlObject.Text
            Select Case controlObject.Name
               ' underline the date
               Case "dateTimePicker"
                  fontObject = New Font("Segoe UI", 9.0F, _
                     FontStyle.Underline)
                  ' draw a box around amount
               Case "amountTextBox"
                  e.Graphics.DrawRectangle(Pens.Black, _
                     amountTextBox.Location.X + leftMargin, _
                     amountTextBox.Location.Y + topMargin - 2, _
                     amountTextBox.Width, amountTextBox.Height)
                  fontObject = controlObject.Font ' default font
               Case Else
                  fontObject = controlObject.Font ' default font
            End Select

            ' set string positions relative to page margins
            xPosition = leftMargin + _
               controlObject.Location.X

            yPosition = topMargin + _
               controlObject.Location.Y

            ' draw text in graphics object
            e.Graphics.DrawString(controlText, fontObject, _
               Brushes.Black, xPosition, yPosition)
         End If
      Next controlObject

      ' draw a line for the payee's name
      e.Graphics.DrawLine(Pens.Black, _
         payeeTextBox.Location.X + leftMargin, _
         payeeTextBox.Location.Y + topMargin + 15, _
         payeeTextBox.Location.X + payeeTextBox.Width + leftMargin, _
         payeeTextBox.Location.Y + topMargin + 15)

      ' draw a line for the amount
      e.Graphics.DrawLine(Pens.Black, _
         dollarsTextBox.Location.X + leftMargin, _
         dollarsTextBox.Location.Y + topMargin + 15, _
         dollarsTextBox.Location.X + dollarsTextBox.Width + _
            leftMargin, _
         dollarsTextBox.Location.Y + topMargin + 15)

      ' draw the memo line
      e.Graphics.DrawLine(Pens.Black, _
         memoTextBox.Location.X + leftMargin, _
         memoTextBox.Location.Y + topMargin + 15, _
         memoTextBox.Location.X + memoTextBox.Width + leftMargin, _
         memoTextBox.Location.Y + topMargin + 15)

      ' draw box around check
      e.Graphics.DrawRectangle(Pens.Black, leftMargin, _
         topMargin, Me.Width, Me.Height - 60)
   End Sub ' document_PrintPage

   ' print document
   Private Sub printButton_Click(ByVal sender As System.Object, _
      ByVal e As System.EventArgs) Handles printButton.Click

      ' create new object to assist in printing
      Dim document As New PrintDocument()

      ' tell PrintDocument where to find PrintPage event handler
      AddHandler document.PrintPage, _
         AddressOf document_PrintPage

      ' if no printers installed, display error message
      If PrinterSettings.InstalledPrinters.Count = 0 Then
         ErrorMessage()
         Return ' exit event handler
      End If

      ' print the document
      document.Print()
   End Sub ' printButton_Click

   ' display document in print preview dialog
   Private Sub previewButton_Click(ByVal sender As System.Object, _
      ByVal e As System.EventArgs) Handles previewButton.Click

      ' create new object to assist in previewing
      Dim document As New PrintDocument()

      ' tell PrintDocument where to find PrintPage event handler
      AddHandler document.PrintPage, _
         AddressOf document_PrintPage

      ' if no printers installed, display error message
      If PrinterSettings.InstalledPrinters.Count = 0 Then
         ErrorMessage()
         Return ' exit event handler
      End If

      previewObject.Document = document ' specify document
      previewObject.ShowDialog() ' show print preview
   End Sub ' previewButton_Click

   ' display an error message to the user
   Sub ErrorMessage()

      MessageBox.Show("No printers installed. You must " & _
         "have a printer installed to preview or print " & _
         "the document.", "Print Error", _
         MessageBoxButtons.OK, MessageBoxIcon.Error)
   End Sub ' ErrorMessage
End Class ' CheckWriterForm

' **************************************************************************
' * (C) Copyright 1992-2009 by Deitel & Associates, Inc. and               *
' * Pearson Education, Inc. All Rights Reserved.                           *
' *                                                                        *
' * DISCLAIMER: The authors and publisher of this book have used their     *
' * best efforts in preparing the book. These efforts include the          *
' * development, research, and testing of the theories and programs        *
' * to determine their effectiveness. The authors and publisher make       *
' * no warranty of any kind, expressed or implied, with regard to these    *
' * programs or to the documentation contained in these books. The authors *
' * and publisher shall not be liable in any event for incidental or       *
' * consequential damages in connection with, or arising out of, the       *
' * furnishing, performance, or use of these programs.                     *
' **************************************************************************